"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.CSSStyleService = void 0;
const tslib_1 = require("tslib");
const di_1 = require("@opensumi/di");
const style_1 = require("../common/style");
class GlobalStyleSheet {
    constructor() {
        const style = document.createElement('style');
        document.body.appendChild(style);
        this.styleSheet = style.sheet;
    }
    insertSelector(selector, rule) {
        const index = this.styleSheet.insertRule(`${selector} { ${rule} }`, this.styleSheet.cssRules.length);
        return {
            index,
            dispose: () => {
                this.removeRuleBySelector(selector);
            },
        };
    }
    removeRuleBySelector(selector) {
        for (let i = this.styleSheet.cssRules.length - 1; i >= 0; i--) {
            if (this.styleSheet.cssRules[i].selectorText === selector) {
                this.styleSheet.deleteRule(i);
            }
        }
    }
    deleteRule(index) {
        this.styleSheet.deleteRule(index);
    }
}
let CSSStyleService = class CSSStyleService {
    constructor() {
        this.globalStyleSheet = new GlobalStyleSheet();
    }
    addClass(classname, style) {
        const rule = createStyleCssText(style);
        if (!rule) {
            return style_1.emptyResult;
        }
        return this.globalStyleSheet.insertSelector(`.${classname}`, rule);
    }
    removeClass(classname) {
        this.globalStyleSheet.removeRuleBySelector(`.${classname}`);
    }
};
CSSStyleService = tslib_1.__decorate([
    (0, di_1.Injectable)(),
    tslib_1.__metadata("design:paramtypes", [])
], CSSStyleService);
exports.CSSStyleService = CSSStyleService;
function createStyleCssText(styles) {
    const texts = [];
    Object.keys(styles).forEach((key) => {
        if (styles[key]) {
            texts.push(toDashSplitForm(key) + ':' + styles[key]);
        }
    });
    return texts.join(';');
}
function toDashSplitForm(key) {
    return key
        .trim()
        .split(/(?=[A-Z])/)
        .join('-')
        .toLowerCase();
}
//# sourceMappingURL=style.service.js.map